bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGamma.move_plates
====================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianGamma.move_plates